==> php3_3.0.orig.tar.gz: php-3.0/functions/php3_bcmath.h <==
/* 
   +----------------------------------------------------------------------+
   | PHP HTML Embedded Scripting Language Version 3.0                     |
   +----------------------------------------------------------------------+
   | Copyright (c) 1997,1998 PHP Development Team (See Credits file)      |
   +----------------------------------------------------------------------+
   | This program is free software; you can redistribute it and/or modify |
   | it under the terms of one of the following licenses:                 |
   |                                                                      |
   |  A) the GNU General Public License as published by the Free Software |
   |     Foundation; either version 2 of the License, or (at your option) |
   |     any later version.                                               |
   |                                                                      |
   |  B) the PHP License as published by the PHP Development Team and     |
   |     included in the distribution in the file: LICENSE                |
   |                                                                      |
   | This program is distributed in the hope that it will be useful,      |
   | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
   | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
   | GNU General Public License for more details.                         |
   |                                                                      |
   | You should have received a copy of both licenses referred to here.   |
   | If you did not, or have any questions about PHP licensing, please    |
   | contact core@php.net.                                                |
   +----------------------------------------------------------------------+
   | Authors: Andi Gutmans <andi@php.net>                                 |
   +----------------------------------------------------------------------+
 */


/* $Id: php3_bcmath.h,v 1.18 1998/05/15 10:57:32 zeev Exp $ */

#ifndef _PHP3_BCMATH_H
#define _PHP3_BCMATH_H

#if COMPILE_DL
#undef WITH_BCMATH
#define WITH_BCMATH 1
#endif

#if WITH_BCMATH

extern php3_module_entry bcmath_module_entry;
#define bcmath_module_ptr &bcmath_module_entry

extern int php3_rinit_bcmath(INIT_FUNC_ARGS);
extern int php3_rend_bcmath(void);
extern void php3_bcmath_add(INTERNAL_FUNCTION_PARAMETERS);
extern void php3_bcmath_sub(INTERNAL_FUNCTION_PARAMETERS);
extern void php3_bcmath_mul(INTERNAL_FUNCTION_PARAMETERS);
extern void php3_bcmath_div(INTERNAL_FUNCTION_PARAMETERS);
extern void php3_bcmath_mod(INTERNAL_FUNCTION_PARAMETERS);
extern void php3_bcmath_pow(INTERNAL_FUNCTION_PARAMETERS);
extern void php3_bcmath_sqrt(INTERNAL_FUNCTION_PARAMETERS);
extern void php3_bcmath_comp(INTERNAL_FUNCTION_PARAMETERS);
extern void php3_bcmath_set_scale(INTERNAL_FUNCTION_PARAMETERS);

#else

#define bcmath_module_ptr NULL

#endif

#endif /* _PHP3_BCMATH_H */

==> php3_3.0.18.orig.tar.gz: php3-3.0.18/functions/php3_bcmath.h <==
/* 
   +----------------------------------------------------------------------+
   | PHP HTML Embedded Scripting Language Version 3.0                     |
   +----------------------------------------------------------------------+
   | Copyright (c) 1997-2000 PHP Development Team (See Credits file)      |
   +----------------------------------------------------------------------+
   | This program is free software; you can redistribute it and/or modify |
   | it under the terms of one of the following licenses:                 |
   |                                                                      |
   |  A) the GNU General Public License as published by the Free Software |
   |     Foundation; either version 2 of the License, or (at your option) |
   |     any later version.                                               |
   |                                                                      |
   |  B) the PHP License as published by the PHP Development Team and     |
   |     included in the distribution in the file: LICENSE                |
   |                                                                      |
   | This program is distributed in the hope that it will be useful,      |
   | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
   | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
   | GNU General Public License for more details.                         |
   |                                                                      |
   | You should have received a copy of both licenses referred to here.   |
   | If you did not, or have any questions about PHP licensing, please    |
   | contact core@php.net.                                                |
   +----------------------------------------------------------------------+
   | Authors: Andi Gutmans <andi@zend.com>                                |
   +----------------------------------------------------------------------+
 */


/* $Id: php3_bcmath.h,v 1.21 2000/04/10 19:29:37 andi Exp $ */

#ifndef _PHP3_BCMATH_H
#define _PHP3_BCMATH_H

#if COMPILE_DL
#undef WITH_BCMATH
#define WITH_BCMATH 1
#endif

#if WITH_BCMATH

extern php3_module_entry bcmath_module_entry;
#define bcmath_module_ptr &bcmath_module_entry

extern int php3_rinit_bcmath(INIT_FUNC_ARGS);
extern int php3_rend_bcmath(void);
extern void php3_bcmath_add(INTERNAL_FUNCTION_PARAMETERS);
extern void php3_bcmath_sub(INTERNAL_FUNCTION_PARAMETERS);
extern void php3_bcmath_mul(INTERNAL_FUNCTION_PARAMETERS);
extern void php3_bcmath_div(INTERNAL_FUNCTION_PARAMETERS);
extern void php3_bcmath_mod(INTERNAL_FUNCTION_PARAMETERS);
extern void php3_bcmath_pow(INTERNAL_FUNCTION_PARAMETERS);
extern void php3_bcmath_sqrt(INTERNAL_FUNCTION_PARAMETERS);
extern void php3_bcmath_comp(INTERNAL_FUNCTION_PARAMETERS);
extern void php3_bcmath_set_scale(INTERNAL_FUNCTION_PARAMETERS);

#else

#define bcmath_module_ptr NULL

#endif

#endif /* _PHP3_BCMATH_H */
